@@ -7,6 +7,8 @@ import argparse
 from contextlib import contextmanager
 import logging
 
+from bml import about
+
 __all__ = ['parse_arguments', 'content_from_file', 'Node', 'ContentType',
            'args', 'Args', 'EMPTY', 'ROOT', 'logger', 'makedepend']
 
@@ -658,6 +660,7 @@ def parse_arguments(description, option_tree=True, option_include_external_files
         include_external_files_parser.add_argument('--no-include-external-files', dest='include_external_files', action='store_false')
         parser.set_defaults(include_external_files=args.include_external_files)  # BML 1.0
 
+    parser.add_argument('--version', action='version', version="%(prog)s (" + about.__version__ + ")")
     # modify the original arguments so it stays the same class object
     parser.parse_args(namespace=args)
 
@@ -673,24 +676,8 @@ def parse_arguments(description, option_tree=True, option_include_external_files
     return args
 
 
-def makedepend(input_filename, output_filename):
-    """Parse input filename for #INCLUDE <include filename> and write them to the output filename in the format
-
-<input filename>: <include filename>
-
-    That way it can be used by make.
-    The output filename may be - which means stdout.
-    """
-    def write_dependencies(input_filename, output, includes):
-        input_basename = os.path.basename(input_filename)
-        output.write('# generated by BML\n')
-        for i in sorted(includes):
-            logger.debug("write include file: " + i)
-            output.write('%s: %s\n' % (input_basename, i))
-        return
-
-    logger.debug("makedepend('%s', '%s')" % (input_filename, output_filename))
-
+def read_dependencies(input_filename):
+    """Parse input filename for #INCLUDE <include filename> and return those include filenames as a set."""
     includes = set()
 
     # move to the directory of the input filename so INCLUDEs will work correctly
@@ -705,11 +692,42 @@ def makedepend(input_filename, output_filename):
                     logger.debug("read include file: " + m.group(1))
                     includes.add(m.group(1))
 
+    return includes
+
+
+def write_dependencies(input_filename, includes, output):
+    """Write to output lines in the following format:
+
+<input filename>: <include filename>
+
+    That way it can be used by make.
+    """
+    input_basename = os.path.basename(input_filename)
+    output.write('# generated by BML\n')
+    for i in sorted(includes):
+        logger.debug("write include file: " + i)
+        output.write('%s: %s\n' % (input_basename, i))
+    return
+
+
+def makedepend(input_filename, output_filename):
+    """Parse input filename for #INCLUDE <include filename> and write them to the output filename in the format
+
+<input filename>: <include filename>
+
+    That way it can be used by make.
+    The output filename may be - which means stdout.
+    """
+
+    logger.debug("makedepend('%s', '%s')" % (input_filename, output_filename))
+
+    includes = read_dependencies(input_filename)
+
     if output_filename == '-':
-        write_dependencies(input_filename, sys.stdout, includes)
+        write_dependencies(input_filename, includes, sys.stdout)
     else:
         with open(output_filename, mode='w', encoding="utf-8") as f:
-            write_dependencies(input_filename, f, includes)
+            write_dependencies(input_filename, includes, f)
 
     return
 
