@@ -601,8 +601,9 @@ def bss2bml(input_spec: FileSpec, output_spec: FileSpec) -> None:
 
 
 def main():
-    bml.args = bml.parse_arguments(description='Convert BSS to BML.', option_tree=False, option_include_external_files=False)
-    if not bml.args.outputfile:
-        bml.args.outputfile = '-' if bml.args.inputfile == '-' else re.sub(r'\..+\Z', '.bml', bml.args.inputfile)
-    bml.logger.debug("Output file:", bml.args.outputfile)
+    bml.args = bml.parse_arguments(description='Convert BSS to BML.', option_tree=False, option_include_external_files=False, option_indentation=False, output_extension='.bml')
     bss2bml(bml.args.inputfile, bml.args.outputfile)
+
+
+if __name__ == '__main__':
+    main()
